2014: The Year the Outrage Machine Started Eating the Real World – Flavorwire
Author: http://flavorwire.com/author/tomflavorpill
Description: If you're inclined to believe #slatepitches, then 2014 was the Year Of Outrage. The Internet's favorite shrine to contrarianism published an interactive calendar earlier this month wherein one can track, day by day, the things about which we ("we" being liberal American adults on the Internet, bas...
Keywords: buzz, pop culture, bill cosby, gamergate, justine sacco, outrage, r. kelly
Date: 2014-12-29T15:00:20+00:00

0

Pop Culture

## 2014: The Year the Outrage Machine Started Eating the Real World

By Tom Hawking on Dec 29, 2014 10:00am
←→
of 2

If you’re inclined to believe #slatepitches, then 2014 was the Year Of Outrage. The Internet’s favorite shrine to contrarianism published an interactive calendar earlier this month wherein one can track, day by day, the things about which we (“we” being liberal American adults on the Internet, basically) were outraged this year. I’m not so sure this year was any different to any other, though: the public has always been fond of being righteously outraged, and for the last few years, at least, the Internet has felt like (and been characterized as) a giant outrage machine. But 2014 did feel like a landmark in one respect: it was the year that the outrage machine proved its power to chew up and spit out people IRL as well as on Twitter or Tumblr. It was a year in which the precipitous fall taken by Bill Cosby, in particular, proved that it’s much, much harder for stars to bury unflattering narratives these days. But the ever-growing power of the angry mob also has pretty terrifying implications if you take an old-fashioned view of what constitutes justice.

There have certainly been plenty of hand-wringing thinkpieces this year lamenting the rise of rage culture (and at least one about how the 300 Sandwiches kerfuffle may have saved us from invading Syria). But notably, two of the biggest stories of 2014 demonstrate the flip-side of that culture: instances where the Internet’s unparalleled ability to disseminate information, and to do so relentlessly, has shone light into hitherto dark places. I’m talking about the fall of Bill Cosby and the near-fall of R. Kelly. Both cases involved allegations that have been on the public record for years, but had nevertheless disappeared from public attention. (And, it should be noted, both involved black men: the sordid history of white celebrities tends to remain buried far more readily than that of men like Kelly and Cosby.)

In both cases, you can trace the story’s reemergence back to a single moment. First there was Jessica Hopper’s interview with Jim DeRogatis in the Village Voice, right at the end of last year, which brought to light (again) the details of the multiple rape accusations against Kelly. Not long after, DeRogatis himself penned a piece entitled, “Why Are People Finally Paying Attention to R. Kelly’s Many Crimes?” DeRogatis’ piece was interesting and perceptive, but the answer could have been summarized in three words: the outrage machine.

It was the same with Cosby: again, all it took was one person to say, “Wait, look at this.” In this case, it was Hannibal Buress flat-out calling Cosby a rapist on stage. The next morning, you could feel the entire Internet rubbing its eyes and saying, “Oh yeah, so what was the deal with Cosby?” As it turned out, the deal with Cosby was just as awful as the Kelly accusations: decades’ worth of women telling stories of having been drugged and assaulted.

Not long after Buress’ performance, the Cosby thinkpieces started to appear. Then one of Cosby’s alleged victims, Barbara Bowman, wrote an op-ed for the Washington Post. And then… well, you can choose your own metaphor: the floodgates opening, the avalanche building, a shower turning into hurricane. However you want to put it, in the course of about three weeks, the attention given to the Cosby accusations increased exponentially, to the point that it could no longer be ignored by anyone (except Cosby himself, who’s still defiantly sticking to a strategy of stonewalling that simply no longer works). The fallout was dramatic: a canceled NBC project, a shelved Netflix special, pulled Cosby Show re-runs all over the place. This wasn’t a case of people online saying nasty things; this was quantifiable and significant damage to whatever’s left of Cosby’s career.

Both with Cosby and with Kelly, we had public interest being reignited in accusations that had been actively suppressed or allowed to just fade away. In the past, it was relatively easy to bury a story: gaslight and discredit the accuser, cozy up to the press, call in some favors. There were only so many ways that news could get out. Once those channels were closed, a story would live on, at best, as a rumor, discussed in bars and over dinner, always laden with an air of doubt and hearsay.

In 2014, it’s almost impossible for that to happen once the story gains any sort of momentum. Thanks in large part to social media, there’s an infinite number of leaks to plug. No doubt some stories are still suppressed before they ever get reported, but once there’s anything on the public record, it just takes one person to notice it and tweet it… and the story’s gone, beyond anyone’s control.

Even if the outrage machine stuck exclusively to eviscerating celebrities who have been burying bad press for decades, its power to destroy would be kind of terrifying. But, of course, it doesn’t. The case that springs to mind immediately is that of the musician Conor Oberst, accused of rape by one Joanie Faircloth in a series of comments on an xoJane article. The pattern was the same: the original comments appeared, they sat idle for a couple of days, not garnering any attention beyond their original forum… then someone reported them, at which point they started doing the rounds on Twitter and Tumblr. And suddenly they were everywhere.

It’s no coincidence, I’m sure, that all three cases — Kelly, Cosby, and Oberst — involved sexual assault. As we all know, it’s a crime that’s notoriously hard to prove and to prosecute, and even more so when years have passed since the alleged incident. In the cases of Kelly and Cosby, it appears from sheer weight of evidence that the Internet’s collective guilty verdict is most likely justified. The case of Oberst was quite a bit different.

As I wrote at the time, the simple fact was that no one knew what had happened except Oberst and his accuser. As so often happens with rape, it was a game of he-said, she-said, except in this case neither he nor she was saying anything — Oberst released a brief statement denying the accusations, and Faircloth went to ground. There was no information beyond a couple of deleted comments made by a woman about which the world knew next to nothing. Of course, because the Internet abhors a vacuum of information, this only served to heighten the rage and speculation. Commentators pronounced Oberst guilty or innocent without the slightest hint of a doubt, on the basis of absolutely nothing beyond personal conviction and confirmation bias.

As it transpired, Faircloth withdrew the allegations after Oberst threatened to sue her. But no one will come out of this story unscathed: there will always be people out there who now believe, no matter what, that Conor Oberst is a rapist. Faircloth, meanwhile, has her credibility left in shreds — there’ll be people to whom she’ll always be the crazy girl who made the false accusation. Either way, the Internet feeding frenzy has done her no favors: if her accusation was true, it seems almost impossible for her to ever pursue it, and if it was false, she most likely needs serious help. Having her story plastered all over the Internet (in violation of her express wishes) did her no more good than it did Oberst.

None of this bothered the Internet judge/jury/executioners, though, who had already happily moved on. The Internet being the Internet, though, what’s forgotten isn’t necessarily gone. The Frisky’s hugely irresponsible “Why I Believe Conor Oberst’s Anonymous Rape Accuser” essay, for instance, is still online, prefaced only by a one-sentence “update” that’s essentially the journalistic equivalent of ¯\_(ツ)_/¯. In cyberspace, accusations never die: they just sit there, somewhere on Google, waiting for people to dredge them up again. It’s for this reason that there have been recent cases in the EU regarding a right to be forgotten.

←→
of 2
View all pages

- ## Recent Features

- 13h

  And We're Back to 'Back to the Future Part II': Links You Need to See

- 14h

  Madonna, Can You Not?

- 15h

  What To Watch on TV: January 4-January 10

- 15h

  After Trans Teen Leelah Alcorn's Suicide, We All Must Do Better

- 17h

  Flavorwire’s Guide to Indie Flicks to See in January

- 17h

  The Confident 'Selfie' Finale Sets Up A Promising Future That We'll Never See

- 18h

  Ten Unique and Funky Literary Magazines To Check Out in 2015

- 19h

  Men of Honor, Vampires, Audiobooks, and 'Gilmore Girls': Highlights From Edward Herrmann's Career

- 20h

  The 5 Best Songs We Heard This Week: Kanye Inspired My First Cry of 2015

- 20h

  Subtly Beautiful Animated "Cinemagraphs" of the World Around Us

- ## Popular Posts

  View All Posts
- 22h

  The Best of Literary Criticism in 2014

- 3d

  The 10 Best Films and TV Shows About Disappearance

- 3d

  2014: The Death of the Postmodern Novel and the Rise of Autofiction

- 4d

  Flavorwire's Guide to (Expiring) Movies to Stream This New Year's Eve

- 4d

  Book Publishing Predictions for 2015

- View All Posts

Follow

### Follow “Flavorwire”

Get every new post delivered to your Inbox.

Join 8,750 other followers

Build a website with WordPress.com